#include "AEEAppGen.h"        // Applet helper file
#include "helloworld2005.bid"		// Applet-specific header that contains class ID


/*-------------------------------------------------------------------
Static function prototypes
-------------------------------------------------------------------*/
static boolean helloworld2005_HandleEvent(AEEApplet * pme, AEEEvent eCode,uint16 wParam, uint32 dwParam);

/*===============================================================================
FUNCTION DEFINITIONS
=============================================================================== */
/*===========================================================================

FUNCTION: AEEClsCreateInstance

DESCRIPTION
This function is invoked while the app is being loaded. All Modules must provide this 
function. Ensure to retain the same name and parameters for this function.
In here, the module must verify the ClassID and then invoke the AEEApplet_New() function
that has been provided in AEEAppGen.c. 

After invoking AEEApplet_New(), this function can do app specific initialization. In this
example, a generic structure is provided so that app developers need not change app specific
initialization section every time except for a call to InitAppData(). This is done as follows:
InitAppData() is called to initialize AppletData instance. It is app developers 
responsibility to fill-in app data initialization code of InitAppData(). App developer
is also responsible to release memory allocated for data contained in AppletData -- this can be
done in FreeAppData().

PROTOTYPE:
int AEEAppCreateInstance(AEECLSID clsID, IShell* pIShell, IModule* pIModule,IApplet** ppApplet)

PARAMETERS:
clsID: [in]: Specifies the ClassID of the applet which is being loaded

pIShell: [in]: Contains pointer to the IShell interface. 

pIModule: pin]: Contains pointer to the IModule interface to the current module to which
this app belongs

ppApplet: [out]: On return, *ppApplet must point to a valid AEEApplet structure. Allocation
of memory for this structure and initializing the base data members is done by AEEApplet_New().

DEPENDENCIES
none

RETURN VALUE
SUCCESS: If the app needs to be loaded and if AEEApplet_New() invocation was successful
EFAILED: If the app does not need to be loaded or if errors occurred in AEEApplet_New().
If this function returns FALSE, the app will not be loaded.

SIDE EFFECTS
none
===========================================================================*/
int AEEClsCreateInstance(AEECLSID ClsId,IShell * pIShell,IModule * pMod,void ** ppObj)
{
	*ppObj = NULL;

	if(AEEApplet_New( sizeof(AEEApplet),                  // Size of our private class
		ClsId,                              // Our class ID
		pIShell,                            // Shell interface
		pMod,                               // Module instance
		(IApplet**)ppObj,                   // Return object
		(AEEHANDLER)helloworld2005_HandleEvent, // Our event handler
		NULL))                              // No special "cleanup" function
		return(AEE_SUCCESS);

	return (EFAILED);
}

/*===========================================================================

FUNCTION helloworld2005_HandleEvent

DESCRIPTION
This is the EventHandler for this app. All events to this app are handled in this
function. All APPs must supply an Event Handler.  

Note - The switch statement in the routine is to demonstrate how event handlers are 
generally structured.  However, realizing the simplicity of the example, the code could
have been reduced as follows:

if(eCode == EVT_APP_START){
IDISPLAY_DrawText();
IDISPLAY_Update();
return(TRUE);
}
return(FALSE);

However, while doing so would have demonstrated how BREW apps can be written in about 8
lines of code (including the app creation function), it might have confused those who wanted 
a bit more practical example.

Also note that the use of "szText" below is provided only for demonstration purposes.  As 
indicated in the documentation, a more practical approach is to load text resources
from the applicaton's resource file.

Finally, note that the ONLY event that an applet must process is EVT_APP_START.  Failure
to return TRUE from this event will indicate that the app cannot be started and BREW
will close the applet.

PROTOTYPE:
boolean helloworld2005_HandleEvent(IApplet * pi, AEEEvent eCode, uint16 wParam, uint32 dwParam)

PARAMETERS:
pi: Pointer to the AEEApplet structure. This structure contains information specific
to this applet. It was initialized during the AppCreateInstance() function.

ecode: Specifies the Event sent to this applet

wParam, dwParam: Event specific data.

DEPENDENCIES
none

RETURN VALUE
TRUE: If the app has processed the event
FALSE: If the app did not process the event

SIDE EFFECTS
none
===========================================================================*/
static boolean helloworld2005_HandleEvent(AEEApplet * pMe, AEEEvent eCode, uint16 wParam, uint32 dwParam)
{  
	AECHAR szText[] = {'T','e','s','t',' ','B','r', 'e', 'w', '\0'};

	switch (eCode){
	  case EVT_APP_START:                        
		  IDISPLAY_DrawText(pMe->m_pIDisplay,    // Display instance
			  AEE_FONT_BOLD,       // Use BOLD font
			  szText,              // Text - Normally comes from resource
			  -1,                  // -1 = Use full string length
			  1,                   // Ignored - IDF_ALIGN_CENTER
			  0,                   // Ignored - IDF_ALIGN_MIDDLE
			  NULL,                // No clipping
			  IDF_ALIGN_CENTER | IDF_ALIGN_MIDDLE);
		  IDISPLAY_Update (pMe->m_pIDisplay);


		  return(TRUE);

	  case EVT_APP_STOP:
		  return(TRUE);


	  default:
		  break;
	}
	return(FALSE);
}


